Inspector class

Inspector can wrap any child, and will display its control panel and information overlay on top of that child.

You should use Inspector as a wrapper to WidgetsApp.builder or MaterialApp.builder.

If isEnabled is null, then Inspector is automatically disabled on production builds (i.e. kReleaseMode is true).

isPanelVisible controls the visibility of the control panel - setting it to false will hide the panel, but the other functionality can still be accessed through keyboard shortcuts. If you want to disable the inspector entirely, use isEnabled.

Inheritance

Constructors

Inspector({Key? key, required Widget child, InspectorController? controller, Alignment alignment = Alignment.center, bool isPanelVisible = true, bool? isEnabled, Widget panelBuilder(BuildContext context, InspectorController controller, Widget child)?})
const

Properties

alignment Alignment
final
child Widget
final
controller InspectorController?
final
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool?
final
isPanelVisible bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
panelBuilder Widget Function(BuildContext context, InspectorController controller, Widget child)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() InspectorState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

maybeOf(BuildContext? context) InspectorState?
of(BuildContext context) InspectorState