InspectorController class
Constructors
-
InspectorController({bool isEnabled = true, bool isWidgetInspectorEnabled = true, bool isWidgetInspectAndCompareEnabled = true, bool isColorPickerEnabled = true, bool isColorSchemeHintEnabled = true, bool isZoomEnabled = true, List<
LogicalKeyboardKey> widgetInspectorShortcuts = const [LogicalKeyboardKey.alt, LogicalKeyboardKey.altLeft, LogicalKeyboardKey.altRight, LogicalKeyboardKey.meta, LogicalKeyboardKey.metaLeft, LogicalKeyboardKey.metaRight], List<LogicalKeyboardKey> widgetInspectAndCompareShortcuts = const [LogicalKeyboardKey.keyY], List<LogicalKeyboardKey> colorPickerShortcuts = const [LogicalKeyboardKey.shift, LogicalKeyboardKey.shiftLeft, LogicalKeyboardKey.shiftRight], List<LogicalKeyboardKey> zoomShortcuts = const [LogicalKeyboardKey.keyZ]})
Properties
-
byteDataStateNotifier
→ ValueNotifier<
ByteData?> -
final
-
colorPickerShortcuts
→ List<
LogicalKeyboardKey> -
final
-
comparedRenderBoxNotifier
→ ValueNotifier<
BoxInfo?> -
final
-
currentRenderBoxNotifier
→ ValueNotifier<
BoxInfo?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hoveredRenderBoxNotifier
→ ValueNotifier<
BoxInfo?> -
final
-
ignoringPointerKey
→ GlobalKey<
State< StatefulWidget> > -
final
- image → Image?
-
no setter
- isColorPickerEnabled → bool
-
final
- isColorSchemeHintEnabled → bool
-
final
- isEnabled → bool
-
final
- isWidgetInspectAndCompareEnabled → bool
-
final
- isWidgetInspectorEnabled → bool
-
final
- isZoomEnabled → bool
-
final
-
modeNotifier
→ ValueNotifier<
InspectorMode> -
final
-
repaintBoundaryKey
→ GlobalKey<
State< StatefulWidget> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedColorImageOffsetNotifier
→ ValueNotifier<
Offset?> -
final
-
selectedColorOffsetNotifier
→ ValueNotifier<
Offset?> -
final
-
selectedColorStateNotifier
→ ValueNotifier<
Color?> -
final
-
stackKey
→ GlobalKey<
State< StatefulWidget> > -
final
-
widgetInspectAndCompareShortcuts
→ List<
LogicalKeyboardKey> -
final
-
widgetInspectorShortcuts
→ List<
LogicalKeyboardKey> -
final
-
zoomImageOffsetNotifier
→ ValueNotifier<
Offset?> -
final
-
zoomOverlayOffsetNotifier
→ ValueNotifier<
Offset?> -
final
-
zoomScaleNotifier
→ ValueNotifier<
double> -
final
-
zoomShortcuts
→ List<
LogicalKeyboardKey> -
final
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPointerExit(
Offset pointerOffset) → void -
onPointerHoverDebounced(
Offset pointerOffset, BuildContext context) → void -
onPointerMove(
Offset pointerOffset, BuildContext context) → void -
onPointerScroll(
PointerScrollEvent scrollEvent) → void -
onTap(
Offset? pointerOffset, BuildContext context) → void -
registerKeyboardHandler(
) → void -
setMode(
InspectorMode mode, {BuildContext? context}) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterKeyboardHandler(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited